@@ -39,7 +39,6 @@ class Geo_common:
         self.excel = excel
         self.main_name = main_name
         self.project_name = project_name
-        self.pipe_dir = pipe_dir
         ######## 以下是main页面的解析
         # series: 合同信息 , dict = {key:value}
         self.series = {}
@@ -115,29 +114,30 @@ class Geo_common:
             self.pipeline_control[k] = v
 
         #### 常用变量:
-        self.pro_dir = self.protocol["project_dir"]
-        self.contract_number = self.series["contract_number"]
-        self.yaml = os.path.join(self.pro_dir,self.contract_number+'.yaml')
+        pro_dir = self.protocol["project_dir"]
+        contract_number = self.series["contract_number"]
+        self.yaml = os.path.join(pro_dir,contract_number+"."+project_name+'.yaml')
         ############ singularity 挂载信息
         roots= []
         self.singularity_args = ''
-        for i in [self.pipe_dir , self.pro_dir] + [self.samples[sample]["raw_file_r1"][0] for sample in self.samples]:
+        for i in [pipe_dir , pro_dir] + [self.samples[sample]["raw_file_r1"][0] for sample in self.samples]:
             i = i.split("/")[1]
             roots.append(i)
         roots = set(roots)
         for i in roots:
             self.singularity_args += "-B /%s:/%s " %(i,i)
-    
-    def generate_shell(self, yaml_file):
+        ########## 生成目录, 拷贝pipeline.yaml
+        os.system("mkdir -p %s/log/slurmlog" %(pro_dir))
+        shutil.copy(os.path.join(pipe_dir,"pipeline.yaml"),pro_dir)
         ########## 分析脚本
         n = 1
         shells = []
         for stage in self.analysis_steps:
-            shell = os.path.join(self.pro_dir, "%s.%s.sh" %(n,stage))
+            shell = os.path.join(pro_dir, "%s.%s.sh" %(n,stage))
             n += 1
             shells.append("sh %s" %(shell))
-            success_msn = "hello, %s 的 %s 已完成，路径为 %s ."%(self.contract_number, stage, self.pro_dir)
-            fail_msn = "hello, %s 的 %s 分析失败，请检查, 路径为 %s ."%(self.contract_number, stage, self.pro_dir)
+            success_msn = "hello, %s 的 %s 已完成，路径为 %s ."%(contract_number, stage, pro_dir)
+            fail_msn = "hello, %s 的 %s 分析失败，请检查, 路径为 %s ."%(contract_number, stage, pro_dir)
             success_talk = ding_talk(success_msn, self.analyst_phone_number)
             fail_talk = ding_talk(fail_msn, self.analyst_phone_number)
             with open(shell,'w') as f:
@@ -146,32 +146,32 @@ snakemake --cluster-config %s/pipeline.yaml --cluster "sbatch -c {cluster.c} -o
 
 if [ $? -eq 0 ];
 then
-    #DingTalk
-    %s
+#DingTalk
+%s
 else
-    #Fail DingTalk
-    %s
+#Fail DingTalk
+%s
 fi
 
-""" %(self.pro_dir, self.singularity_args,self.pipe_dir, stage, yaml_file, self.pro_dir,
+""" %(pro_dir, self.singularity_args,pipe_dir, stage, self.yaml, pro_dir,
     success_talk,
     fail_talk))
 
         ######### 生成报告 和 上传 脚本
-        report_shell = os.path.join(self.pro_dir, "report.sh")
+        report_shell = os.path.join(pro_dir, "report.sh")
         with open(report_shell,'w') as f:
             f.write("""
-%s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp/ && \\
+    %s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp/ && \\
 
-%s/script/Report.py --odir %s/Report --yaml %s
-"""%(self.pipe_dir, yaml_file, self.pro_dir,
-    self.pipe_dir, self.pro_dir, self.yaml))
+    %s/script/Report.py --odir %s/Report --yaml %s
+    """%(pipe_dir, self.yaml, pro_dir,
+    pipe_dir, pro_dir, self.yaml))
 
-        upload_shell = os.path.join(self.pro_dir, "upload.sh")
-        oss_path = get_oss_path(self.contract_number)
-        msn = "hello, %s 的 上传已完成，路径为 %s ."%(self.contract_number, oss_path)
+        upload_shell = os.path.join(pro_dir, "upload.sh")
+        oss_path = get_oss_path(contract_number)
+        msn = "hello, %s 的 上传已完成，路径为 %s ."%(contract_number, oss_path)
         talk = ding_talk(msn, self.analyst_phone_number)
-        fail_msn = "hello, %s 的 上传失败! 路径为 %s ."%(self.contract_number, oss_path)
+        fail_msn = "hello, %s 的 上传失败! 路径为 %s ."%(contract_number, oss_path)
         fail_talk = ding_talk(fail_msn, self.analyst_phone_number)
         with open(upload_shell,"w") as f:
             f.write("""
@@ -183,23 +183,19 @@ python3 -m excelParse.upload -i %s/Upload/ -o %s
 
 if [ $? -eq 0 ];
 then
-    #DingTalk
-    %s
+#DingTalk
+%s
 else
-    #Fail DingTalk
-    %s
+#Fail DingTalk
+%s
 fi
 
-""" %(self.pro_dir,
-      self.pipe_dir, yaml_file, self.pro_dir,
-      self.pro_dir , oss_path,
-      talk,
-      fail_talk))
+""" %(pro_dir,
+        pipe_dir, self.yaml, pro_dir,
+        pro_dir , oss_path,
+        talk,
+        fail_talk))
 
         # 打印运行命令
-        msn = "\n\033[34m%s\033[0m 的shell脚本已生成。shell脚本路径为: \033[34m%s\033[0m .\n\n您可以选择运行以下命令：\n%s"%(self.contract_number, self.pro_dir , "\n".join(shells))
+        msn = "\n\033[34m%s\033[0m 的shell脚本已生成。shell脚本路径为: \033[34m%s\033[0m .\n\n您可以选择运行以下命令：\n%s"%(contract_number, pro_dir , "\n".join(shells))
         print(msn)
-
-    def copy_mkdir(self):
-        os.system("mkdir -p %s/log/slurmlog" %(self.pro_dir))
-        shutil.copy(os.path.join(self.pipe_dir,"pipeline.yaml"),self.pro_dir)
\ No newline at end of file
